@@ -7,6 +7,6 @@ from wiederverwendbar.logger.helper import (logger_exists,
                                             remove_logger)
 from wiederverwendbar.logger.log_levels import (LogLevels)
 from wiederverwendbar.logger.logger import (Logger)
+from wiederverwendbar.logger.redirect_level import (redirect_level)
 from wiederverwendbar.logger.settings import (LoggerSettings)
 from wiederverwendbar.logger.singleton import (LoggerSingleton)
-from wiederverwendbar.logger.terminal_out_files import (TerminalOutFiles)
