@@ -1,3 +1,4 @@
+import logging
 from enum import Enum
 
 
@@ -12,3 +13,6 @@ class LogLevels(str, Enum):
     WARNING = "WARNING"
     INFO = "INFO"
     DEBUG = "DEBUG"
+
+    def get_level_number(self) -> int:
+        return int(logging.getLevelName(self.value))
