@@ -1,3 +1,4 @@
+import warnings
 from typing import Any, Optional, Callable, Union, TYPE_CHECKING
 
 from sqlalchemy import inspect
@@ -6,6 +7,7 @@ from sqlalchemy.orm import Session, QueryableAttribute
 from sqlalchemy.orm.exc import DetachedInstanceError
 
 from wiederverwendbar.default import Default
+from wiederverwendbar.functions.get_pretty_str import get_pretty_str
 from wiederverwendbar.sqlalchemy.raise_has_not_attr import raise_has_not_attr
 
 if TYPE_CHECKING:
@@ -141,7 +143,18 @@ class Base:
         super().__init__(*args, **kwargs)
 
     def __str__(self):
-        return f"{self.__class__.__name__}({', '.join([f'{column_name}={getattr(self, column_name)}' for column_name in self.__str_columns__])})"
+        out = f"{self.__class__.__name__}("
+        for attr_name in self.__str_columns__:
+            if type(attr_name) is tuple:
+                attr_view_name = attr_name[0]
+                attr_name = attr_name[1]
+            else:
+                attr_view_name = attr_name
+            if not hasattr(self, attr_name):
+                warnings.warn(f"Attribute '{attr_name}' is not set for {self}.")
+            out += f"{attr_view_name}={get_pretty_str(getattr(self, attr_name))}, "
+        out = out[:-2] + ")"
+        return out
 
     def __repr__(self):
         return self.__str__()
@@ -247,7 +260,7 @@ class Base:
     @classmethod
     def new(cls,
             session: Optional[Session] = None,
-            **kwargs) -> "Base":
+            **kwargs) -> Union["Base", Any]:
         session_created, session = cls.session(session=session)
 
         # noinspection PyArgumentList
@@ -279,7 +292,7 @@ class Base:
     @classmethod
     def get_all(cls,
                 *criterion: Union[ColumnExpressionArgument[bool], bool],
-                order_by: Union[str, QueryableAttribute, None] = None,
+                order_by: Union[str, QueryableAttribute, Any, None] = None,
                 order_desc: bool = False,
                 rows_per_page: Optional[int] = None,
                 page: int = 1,
@@ -287,7 +300,7 @@ class Base:
                 as_dict: bool = False,
                 dict_columns: Union[list[DictColumn], Default] = Default(),
                 session: Optional[Session] = None,
-                **kwargs: Any) -> list[Union["Base", None, dict[str, Any]]]:
+                **kwargs: Any) -> list[Union["Base", None, dict[str, Any], Any]]:
         session_created, session = cls.session(session=session)
 
         # get order by
@@ -351,7 +364,7 @@ class Base:
             as_dict: bool = False,
             dict_columns: Union[list[DictColumn], Default] = Default(),
             session: Optional[Session] = None,
-            **kwargs: Any) -> Union["Base", None, dict[str, Any]]:
+            **kwargs: Any) -> Union["Base", None, dict[str, Any], Any]:
         session_created, session = cls.session(session=session)
 
         if criterion:
